==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/s3_bucket_acl/S3BucketAclAccessControlPolicyGrant.java <==
package com.hashicorp.cdktf.providers.aws.s3_bucket_acl;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:55.376Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.s3BucketAcl.S3BucketAclAccessControlPolicyGrant")
@software.amazon.jsii.Jsii.Proxy(S3BucketAclAccessControlPolicyGrant.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface S3BucketAclAccessControlPolicyGrant extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_acl#permission S3BucketAcl#permission}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getPermission();

    /**
     * grantee block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/s3_bucket_acl#grantee S3BucketAcl#grantee}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.s3_bucket_acl.S3BucketAclAccessControlPolicyGrantGrantee getGrantee() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link S3BucketAclAccessControlPolicyGrant}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link S3BucketAclAccessControlPolicyGrant}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<S3BucketAclAccessControlPolicyGrant> {
        java.lang.String permission;
        com.hashicorp.cdktf.providers.aws.s3_bucket_acl.S3BucketAclAccessControlPolicyGrantGrantee grantee;

        /**
         * Sets the value of {@link S3BucketAclAccessControlPolicyGrant#getPermission}
         * @param permission Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_acl#permission S3BucketAcl#permission}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder permission(java.lang.String permission) {
            this.permission = permission;
            return this;
        }

        /**
         * Sets the value of {@link S3BucketAclAccessControlPolicyGrant#getGrantee}
         * @param grantee grantee block.
         *                Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/s3_bucket_acl#grantee S3BucketAcl#grantee}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder grantee(com.hashicorp.cdktf.providers.aws.s3_bucket_acl.S3BucketAclAccessControlPolicyGrantGrantee grantee) {
            this.grantee = grantee;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link S3BucketAclAccessControlPolicyGrant}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public S3BucketAclAccessControlPolicyGrant build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link S3BucketAclAccessControlPolicyGrant}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements S3BucketAclAccessControlPolicyGrant {
        private final java.lang.String permission;
        private final com.hashicorp.cdktf.providers.aws.s3_bucket_acl.S3BucketAclAccessControlPolicyGrantGrantee grantee;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.permission = software.amazon.jsii.Kernel.get(this, "permission", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.grantee = software.amazon.jsii.Kernel.get(this, "grantee", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.s3_bucket_acl.S3BucketAclAccessControlPolicyGrantGrantee.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.permission = java.util.Objects.requireNonNull(builder.permission, "permission is required");
            this.grantee = builder.grantee;
        }

        @Override
        public final java.lang.String getPermission() {
            return this.permission;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.s3_bucket_acl.S3BucketAclAccessControlPolicyGrantGrantee getGrantee() {
            return this.grantee;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("permission", om.valueToTree(this.getPermission()));
            if (this.getGrantee() != null) {
                data.set("grantee", om.valueToTree(this.getGrantee()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.s3BucketAcl.S3BucketAclAccessControlPolicyGrant"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            S3BucketAclAccessControlPolicyGrant.Jsii$Proxy that = (S3BucketAclAccessControlPolicyGrant.Jsii$Proxy) o;

            if (!permission.equals(that.permission)) return false;
            return this.grantee != null ? this.grantee.equals(that.grantee) : that.grantee == null;
        }

        @Override
        public final int hashCode() {
            int result = this.permission.hashCode();
            result = 31 * result + (this.grantee != null ? this.grantee.hashCode() : 0);
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/s3_bucket_acl/S3BucketAclAccessControlPolicyGrant.java <==
package com.hashicorp.cdktf.providers.aws.s3_bucket_acl;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:11.450Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.s3BucketAcl.S3BucketAclAccessControlPolicyGrant")
@software.amazon.jsii.Jsii.Proxy(S3BucketAclAccessControlPolicyGrant.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface S3BucketAclAccessControlPolicyGrant extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/s3_bucket_acl#permission S3BucketAcl#permission}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getPermission();

    /**
     * grantee block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/s3_bucket_acl#grantee S3BucketAcl#grantee}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.s3_bucket_acl.S3BucketAclAccessControlPolicyGrantGrantee getGrantee() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link S3BucketAclAccessControlPolicyGrant}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link S3BucketAclAccessControlPolicyGrant}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<S3BucketAclAccessControlPolicyGrant> {
        java.lang.String permission;
        com.hashicorp.cdktf.providers.aws.s3_bucket_acl.S3BucketAclAccessControlPolicyGrantGrantee grantee;

        /**
         * Sets the value of {@link S3BucketAclAccessControlPolicyGrant#getPermission}
         * @param permission Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/s3_bucket_acl#permission S3BucketAcl#permission}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder permission(java.lang.String permission) {
            this.permission = permission;
            return this;
        }

        /**
         * Sets the value of {@link S3BucketAclAccessControlPolicyGrant#getGrantee}
         * @param grantee grantee block.
         *                Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/s3_bucket_acl#grantee S3BucketAcl#grantee}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder grantee(com.hashicorp.cdktf.providers.aws.s3_bucket_acl.S3BucketAclAccessControlPolicyGrantGrantee grantee) {
            this.grantee = grantee;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link S3BucketAclAccessControlPolicyGrant}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public S3BucketAclAccessControlPolicyGrant build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link S3BucketAclAccessControlPolicyGrant}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements S3BucketAclAccessControlPolicyGrant {
        private final java.lang.String permission;
        private final com.hashicorp.cdktf.providers.aws.s3_bucket_acl.S3BucketAclAccessControlPolicyGrantGrantee grantee;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.permission = software.amazon.jsii.Kernel.get(this, "permission", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.grantee = software.amazon.jsii.Kernel.get(this, "grantee", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.s3_bucket_acl.S3BucketAclAccessControlPolicyGrantGrantee.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.permission = java.util.Objects.requireNonNull(builder.permission, "permission is required");
            this.grantee = builder.grantee;
        }

        @Override
        public final java.lang.String getPermission() {
            return this.permission;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.s3_bucket_acl.S3BucketAclAccessControlPolicyGrantGrantee getGrantee() {
            return this.grantee;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("permission", om.valueToTree(this.getPermission()));
            if (this.getGrantee() != null) {
                data.set("grantee", om.valueToTree(this.getGrantee()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.s3BucketAcl.S3BucketAclAccessControlPolicyGrant"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            S3BucketAclAccessControlPolicyGrant.Jsii$Proxy that = (S3BucketAclAccessControlPolicyGrant.Jsii$Proxy) o;

            if (!permission.equals(that.permission)) return false;
            return this.grantee != null ? this.grantee.equals(that.grantee) : that.grantee == null;
        }

        @Override
        public final int hashCode() {
            int result = this.permission.hashCode();
            result = 31 * result + (this.grantee != null ? this.grantee.hashCode() : 0);
            return result;
        }
    }
}
